#!/bin/sh


# Copyright [2015] [O.Klemke]
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


Prog=pi_powerbtn
Script=$(basename $0)

test_it() {
echo "testing:"
if  $(which gcc >/dev/null  ) ;then  echo  "gcc compiler found :-)"    ;else  echo "error: no gcc compiler available :-("; exit 1 ;fi
if  $(which gpio >/dev/null ) ;then  echo "gpio framework found :-)"    ;else  echo "error: no gpio framework available :-("; exit 1 ;fi
LibDir=`dirname $(which gpio) | sed -e 's,bin,lib/,'`
t_file=$LibDir"libwiringPi.so"
if  $(test -x $t_file)  ;then  echo "$t_file found :-)"    ;else echo "error: no $t_file available :-("; exit 1 ; fi
t_file=$LibDir"libwiringPiDev.so"
if  $(test -x $t_file)  ;then  echo "$t_file found :-)"    ;else echo "error: no $t_file available :-("; exit 1 ; fi
t_file=$PWD/$Prog.c
if  $(test -f $t_file)  ;then  echo "$t_file found :-)"    ;else echo "error: no $t_file available :-("; exit 1 ; fi
t_file=$PWD/$Prog.h
if  $(test -f $t_file)  ;then  echo "$t_file found :-)"    ;else echo "error: no $t_file available :-("; exit 1 ; fi

}

build_it() {
rm -- ./$Prog
echo "\n compiling"
if $(gcc  -L/usr/local/lib -I/usr/local/include -Wall  -lwiringPi -lwiringPiDev -lpthread -lm -I.  -O2 $Prog.c  -o $Prog )
then
echo  " $Prog successful compiled :-)"
else
echo  "compiling went wrong :-("
exit 1
fi
}

install_it() {
if $( test `id -u` -eq 0 )
then
echo "installing:"
install -v -m 0755 -g root -o root  $Prog /usr/sbin
install -v -m 0750 -g root -o root  $Prog.init /etc/init.d/$Prog
insserv -v -r $Prog
insserv -v $Prog
else
echo  "\n !! Installing failed, you are not root !! \n for installing as normal user \n \$> sudo $Script install \n or copy the program $Prog to a place you like"
exit 1
fi
}

uninstall_it() {
if $( test `id -u` -eq 0 )
then
echo "uninstalling:"
insserv -v -r $Prog
rm -fv -- /etc/init.d/$Prog
rm -fv -- /usr/sbin/$Prog
else
echo  "\n !! Uninstalling failed, you are not root !! \n for uninstalling as normal user \n \$> sudo $Script uninstall \n or remove the program $Prog from a place you have it coppied to."
exit 1
fi
}

case "$1" in
test)
	test_it
	exit 0
	;;
build)
	test_it
	build_it
	exit 0
	;;
install)
	install_it
	exit 0
	;;
uninstall)
	uninstall_it
	exit 0
	;;
-h|--help|help)
	echo "This $Script licensed under the Apache License, Version 2.0"
	echo "Copyright [2015] [O.Klemke] see http://www.apache.org/licenses/LICENSE-2.0"
	echo
	echo $Script" test              - for testing if a build is possible"
	echo $Script" build or nothing  - for testing and building (it's default)"
	echo $Script" install           - for installing  (you have to be root)"
	echo $Script" uninstall         - for uninstalling  (you have to be root)"
	echo $Script" help              - for this message"
	exit 0
	;;
*)
	test_it
	build_it
	echo "\n !! nothing is installed yet !! \n for installing as root #> $0 install \n as normal user \$> sudo $0 install \n or copy the program $Prog to a place you like" 
	exit 0
	;;
esac








